==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftMl.md <==
# AmazonRedshiftMl


```text
aws-20210730/Resource/Analytics/AmazonRedshiftMl
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')
```



| Illustration | AmazonRedshiftMl | AmazonRedshiftMlCard | AmazonRedshiftMlGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMl.png) | ![illustration for AmazonRedshiftMl](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMl.Local.png) | ![illustration for AmazonRedshiftMlCard](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMlCard.Local.png) | ![illustration for AmazonRedshiftMlGroup](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMlGroup.Local.png) |




## AmazonRedshiftMl

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMl
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMl('AmazonRedshiftMl', 'Amazon Redshift Ml', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMl
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMl('AmazonRedshiftMl', 'Amazon Redshift Ml', 'an optional tech label')
@enduml
```

## AmazonRedshiftMlCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlCard('AmazonRedshiftMlCard', 'Amazon Redshift Ml Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlCard('AmazonRedshiftMlCard', 'Amazon Redshift Ml Card', 'an optional description')
@enduml
```

## AmazonRedshiftMlGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlGroup('AmazonRedshiftMlGroup', 'Amazon Redshift Ml Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlGroup('AmazonRedshiftMlGroup', 'Amazon Redshift Ml Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftMl.md <==
# AmazonRedshiftMl


```text
aws-20210730/Resource/Analytics/AmazonRedshiftMl
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')
```



| Illustration | AmazonRedshiftMl | AmazonRedshiftMlCard | AmazonRedshiftMlGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMl.png) | ![illustration for AmazonRedshiftMl](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMl.Local.png) | ![illustration for AmazonRedshiftMlCard](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMlCard.Local.png) | ![illustration for AmazonRedshiftMlGroup](../../../aws-20210730/Resource/Analytics/AmazonRedshiftMlGroup.Local.png) |




## AmazonRedshiftMl

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMl
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMl('AmazonRedshiftMl', 'Amazon Redshift Ml', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMl
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMl('AmazonRedshiftMl', 'Amazon Redshift Ml', 'an optional tech label')
@enduml
```

## AmazonRedshiftMlCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlCard('AmazonRedshiftMlCard', 'Amazon Redshift Ml Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlCard('AmazonRedshiftMlCard', 'Amazon Redshift Ml Card', 'an optional description')
@enduml
```

## AmazonRedshiftMlGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlGroup('AmazonRedshiftMlGroup', 'Amazon Redshift Ml Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftMlGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftMl')

' renders the element
AmazonRedshiftMlGroup('AmazonRedshiftMlGroup', 'Amazon Redshift Ml Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
